@@ -223,7 +223,7 @@ void svmtrain (double *x, int *r, int *c,
 	       int    *rowindex, int *colindex,
 	       int    *svm_type,
 	       int    *kernel_type,
-	       double *degree,
+	       int    *degree,
 	       double *gamma,
 	       double *coef0,
 	       double *cost,
@@ -365,7 +365,7 @@ void svmpredict  (int    *decisionvalues,
 
 		  int    *svm_type,
 		  int    *kernel_type,
-		  double *degree,
+		  int    *degree,
 		  double *gamma,
 		  double *coef0,
 
@@ -462,7 +462,7 @@ void svmwrite (double *v, int *r, int *c,
 
 		  int    *svm_type,
 		  int    *kernel_type,
-		  double *degree,
+		  int    *degree,
 		  double *gamma,
 		  double *coef0,
 
